@@ -1,4 +1,4 @@
-from src.rocketgym.environment import Environment
+from rocketgym.environment import Environment
 import random
 
 env = Environment()
